@@ -235,7 +235,7 @@ class grep(TextOp):
     reverse = False
     pattern = ''
     @classmethod
-    def op(cls,text,pattern=None,key = None, *args,**kwargs):
+    def op(cls,text,pattern=None,key = None, has_key = None, *args,**kwargs):
         if pattern is None:
             pattern = cls.pattern
         regex = re.compile(pattern,cls.flags)
@@ -244,6 +244,9 @@ class grep(TextOp):
                 if isinstance(line,basestring):
                     if bool(regex.search(stru(line))) != cls.reverse:  # kind of XOR with cls.reverse
                         yield line
+                elif has_key is not None:
+                    if has_key in line != cls.reverse:  # kind of XOR with cls.reverse
+                        yield line
                 elif key is None:
                     if bool(regex.search(stru(line))) != cls.reverse:  # kind of XOR with cls.reverse
                         yield line
@@ -350,7 +353,7 @@ class grepc(TextOp):
     pattern = ''
     exit_on_found = False
     @classmethod
-    def op(cls,text,pattern=None,key = None,*args,**kwargs):
+    def op(cls,text,pattern=None,key = None, has_key = None,*args,**kwargs):
         if text is None:
             return 0
         if pattern is None:
@@ -364,6 +367,11 @@ class grepc(TextOp):
                         count += 1
                         if cls.exit_on_found:
                             break
+                elif has_key is not None:
+                    if has_key in line != cls.reverse:  # kind of XOR with cls.reverse
+                        count += 1
+                        if cls.exit_on_found:
+                            break
                 elif key is None:
                     if bool(regex.search(stru(line))) != cls.reverse:  # kind of XOR with cls.reverse
                         count += 1
